/**************************************************************************************************
	Developed by: the Colorado Health Institute (CHI)
	Contact Information: 
		Glenn Goodrich
		303-831-4200 x225
		goodrichg@coloradohealthinstitute.org

	The 2009 rural physician public use data file was created with a 64-bit  
	version of SAS 9.2 on a 64-bit MS Windows operating system. If this data file will be 
	used with a 32-bit version of SAS 9.2 or earlier, the data file needs to be reassigned, 
	through a DATA STEP, so that it can subsequently assign the SAS formats correctly.

	The following code will execute the necessary DATA STEP described above and then assign 
	the SAS formats to the variables included in the physician file.

	INPUT: rurphy09_puf.sas7bdat (64-bit SAS 9.2 data file from CHI)
	OUTPUT: a data file compatible with the user's version of SAS, with its associated SAS formats 

	NOTATION:
		>> USER INPUT <<;
		indicates all places in the beginning of the code where the user 
		should input information.
	
***************************************************************************************************/
options mprint mlogic symbolgen;
%global filename lib fmtlib;

************************** USER INPUT REQUIRED FOR THIS SECTION ONLY *******************************;

*>> USER INPUT <<;
* INSTRUCTIONS: provide a name for the SAS library associated with the location of the final 
* version of the data file
* (Example: lib = Survey);
%let lib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where the final version of the data file will be stored
* (Example: "C:\MyData");
libname &lib. "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for FINAL version of the data file (it must have a different filename 
* than the CHI version if it will be stored in the SAME directory)
* (Example: filename = SurveyData);
%let filename = ;


*>> USER INPUT <<;
* INSTRUCTIONS: directory path name for where the CHI version of the Research data file is located
* (Example: "C:\MyData\CHI");
libname LIB1 "";

*>> USER INPUT <<;
* INSTRUCTIONS: name for SAS library where the formats with be stored 
* (Example: fmtlib = rpfmt);
%let fmtlib = ;

*>> USER INPUT <<;
* INSTRUCTIONS: directory pathname for where format catalog will be stored
* (Example: "C:\MyData\Formats");
libname &fmtlib. "";

***************************************** END USER INPUT ******************************************
***************************************************************************************************;


options fmtsearch=(&fmtlib.);

* this DATA STEP will restructure the SAS data file to be compatible with user's version of SAS;
data &lib..&filename.;set lib1.rurphy09_puf;run;
proc format library=&fmtlib.;
value $rp09_50char
'-9'		="Missing"
'-8'		=">Not Applicable<"
'-7'		='>Skip pattern violation<'
'-6'		='>Invalid answer/out of range<'
other=[$50.]
;
value $rp09_st
'-9'		="Missing"
'-8'		=">Not Applicable<"
'-7'		='>Skip pattern violation<'
'-6'		='>Invalid answer/out of range<'
'AA'		="Armed Forces -Americas"
'AE'		="Armed Forces -Europe, Canada, Africa, Middle East"
'AK'		="Alaska"
'AL'		="Alabama"
'AP'		="Armed Forced -Pacific"
'AR'		="Arkansas"
'AS'		="American Samoa"
'AZ'		="Arizona"
'CA'		="California"
'CO'		="Colorado"
'CT'		="Connecticut"
'CM' 		="Northern Mariana Islands"
'MP'		="Northern Mariana Islands"
'DC'		="District of Columbia"
'DE'		="Delaware"
'FL'		="Florida"
'FM'		="Federated States of Micronesia"
'FO'		="Foreign Country"
'GA'		="Georgia"
'GU'		="Guam"
'HI'		="Hawaii"
'IA'		="Iowa"
'ID'		="Idaho"
'IL'		="Illinois"
'IN'		="Indiana"
'KS'		="Kansas"
'KY'		="Kentucky"
'LA'		="Louisiana"
'MA'		="Massachusetts"
'MD'		="Maryland"
'ME'		="Maine"
'MH'		="Marshall Islands"
'MI'		="Michigan"
'MN'		="Minnesota" 
'MO'		="Missouri"    
'MS'		="Mississippi"
'MT'		="Montana"
'NC'		="North Carolina"
'ND'		="North Dakota"
'NE'		="Nebraska"
'NH'		="New Hampshire"
'NJ'		="New Jersey"
'NM'		="New Mexico"
'NV'		="Nevada"
'NY'		="New York"
'OH'		="Ohio"
'OK'		="Oklahoma"
'OR'		="Oregon"
'PA'		="Pennsylvania"
'PR'		="Puerto Rico"
'PW'		="Palau"
'RI'		="Rhode Island"
'SC'		="South Carolina"
'SD'		="South Dakota"
'TN'		="Tennessee"
'TX'		="Texas"
'UT'		="Utah"
'VA'		="Virginia"
'VI'		="US Virgin Islands"
'VT'		="Vermont"
'WA'		="Washington"
'WI'		="Wisconsin"
'WV'		="West Virginia"
'WY'		="Wyoming"
'XX'		="Foreign Country"
other		=[$2.]
;
value rp09_3imp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Very Important"
2="Somewhat Important"
3="Not Important"
;
value rp09_adeqb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Indifferent or inadequate (3/4/5)"
1="Adequate (1/2)"
2="N/A"
;
value rp09_charcr
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="None"
2="$2,500 or less"
3="$2,501 to $5,000"
4="$5,001 to $10,000"
5="$10,001 to $25,000"
6="$25,001 to $35,000"
7="$35,001 to $50,000"
8="More than $50,000"
9="Do not know"
10="N/A"
;
value rp09_degr
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="MD"
1="DO"
;
value rp09_gend
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Male"
0="Female"
;
value rp09_grwup
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Rural"
2="Suburban"
3="Urban"
;
value rp09_income
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="$75,000 or less"
2="$75,001 to $100,000"
3="$100,001 to $125,000"
4="$125,001 to $150,000"
5="$150,001 to $175,000"
6="$175,001 to $200,000"
7="$200,001 to $250,000"
8="More than $250,000"
;
value rp09_intb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Not interested or indifferent (3/4/5)"
1="Very interested, levels 1/2"
2="N/A"
;
value rp09_numb
-9			="Missing"
-8			=">Not Applicable<"
-7			=">Skip pattern violation<"
-6			=">Invalid answer/out of range<"
other	=[8.]
;
value rp09_pracb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Full owner"
2="Part owner"
3="Employee"
4="Independent contractor"
5="Other/Locum tenens"
;
value rp09_prepb
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Not prepared or indifferent (3/4/5)"
1="Prepared, (1/2)"
2="N/A"
;
value rp09_q27a
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-10 percent"
2="11-20 percent"
3="21-30 percent"
4="31-40 percent"
5="41-50 percent"
6="51-60 percent"
7="61 or more percent"
;
value rp09_q27b
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1-10 percent"
3="11-20 percent"
4="21-30 percent"
5="31-40 percent"
6="41 percent or more"
;
value rp09_q27c
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1-10 percent"
3="11-20 percent"
4="21 percent or more"
;
value rp09_q27d
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1-5 percent"
3="6 percent or more"
;
value rp09_q27e
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1 percent or more"
;
value rp09_q27f
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0 percent"
2="1-10 percent"
3="11 percent or more"
;
value rp09_stfmdlgp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Solo practice"
2="Solo practice with non-physician provider(s)"
3="Partnership (2 physicians) w or w/o non-physician provider"
4="Group practice (3+ physicians)"
5="Group practice (3+ physicians) with non-physician provider"
;
value rp09_urban
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Rural"
1="Urban"
;
value rp09_visop
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="I am satisfied with the number of patient visits in my practice"
2="I have too many patient visits in my practice"
3="I have too few patient visits in my practice"
4="N/A"
;
value rp09_yn
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="No"
1="Yes"
2="N/A"
;
value rp09agegrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-44"
2="45-54"
3="55 and older"
;
value rp09brthyrgp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="1954 or before"
2="1955-1964"
3="1965 or after"
;
value rp09cntmedhrsgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-30 hours"
2="31-50 hours"
3="51-70 hours"
4="71 hours or more"
;
value rp09daysoncallgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="No days"
2="1-7 days"
3="8-14 days"
4="15-21 days"
5="22 days or more"
;
value rp09gdrnmyrgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-15 years"
2="16-25 years"
3="26-35 years"
4="36 or more"
;
value rp09gradco
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Did not graduate in CO"
1="Did graduate in CO"
;
value rp09gradyrgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="1973 or before"
2="1974-1983"
3="1984-1993"
4="1994 to present"
;
value rp09grdagegrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-25 years old"
2="26-35 years old"
3="36 and older"
;
value rp09hrsdircrgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-20 hours"
2="21-31 hours"
3="32-39 hours"
4="40-49 hours"
5="50 hours or more"
;
value rp09hrsprofgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-20 hours"
2="21-31 hours"
3="32-39 hours"
4="40-49 hours"
5="50 hours or more"
;
value rp09mtrngrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="0 months"
1="1 months"
2="2 months"
3="3 months"
4="4 or more months"
;
value rp09pol
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Indifferent or not important (3,4,5)"
1="Important or very important (1,2)"
2="N/A"
;
value rp09praclocgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Community health clinic"
2="Hospital emergency department"
3="Hospital outpatient/satellite clinic"
4="Private clinic or office"
5="All other practice locations"
;
value rp09pracyrgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-3 years"
2="4-7 years"
3="8-13 years"
4="14-22 years"
5="23 years or more"
;
value rp09prstatc
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Full-time, actively seeing patients"
2="Part-time, actively seeing patients"
3="Retired, not seeing patients"
4="Other"
;
value rp09racegrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Other race"
1="White"
;
value rp09satis
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
0="Not satisfied or indifferent (3/4/5)"
1="Satisfied (1/2)"
2="N/A"
;
value rp09specgrp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="Anesthesia"
2="Emergency Medicine"
3="Family Medicine"
4="Internal Medicine"
5="Obstetrics and Gynecology"
6="General Surgery"
7="Other specialty"
;
value rp09vis08grp
-9="Missing"
-8=">Not Applicable<"
-7=">Skip pattern violation<"
-6=">Invalid answer/out of range<"
1="0-1000 visits"
2="1001-3000 visits"
3="3001-5000 visits"
4="5001-11000 visits"
5="More than 11000 visits"
;
value rprucgp
-9='Missing'
-8='>Not Applicable<'
1='Isolated'
2='Rural Small'
3='Rural Large'
;
run;
proc datasets library = &lib.;
	modify &filename.;
	format mostdif_spec_grp $RP09_50CHAR.;
	format primary_state_from_zip $RP09_ST.;
	format fac_prac_grewuprur fac_prac_costlv fac_prac_recr fac_prac_srvpop fac_prac_recrcol
	fac_prac_jobspouse fac_prac_earnpot fac_prac_rcrtinc fac_prac_indep fac_prac_wkenv
	fac_prac_bought fac_prac_sp_rur fac_prac_locint fac_prac_svnatcore fac_prac_raisechl
	fac_prac_ret_rurco RP09_3IMP.;
	format class_matcare_grp class_ortho_sp_grp class_prepostop_grp class_trauma_grp class_critcare_grp
	class_occhlth_grp class_behv_grp class_phycog_imp_grp class_tele_elec_grp class_practeams_grp
	class_geria_cr_grp resid_matcare_grp resid_ortho_grp resid_prepostop_grp resid_trauma_grp
	resid_critcare_grp resid_occhlth_grp resid_behv_grp resid_phycog_imp_grp resid_tele_elec_grp
	resid_practeams_grp resid_geria_cr_grp RP09_ADEQB.;
	format charcare RP09_CHARCR.;
	format degree RP09_DEGR.;
	format gender RP09_GEND.;
	format grewup_location RP09_GRWUP.;
	format income RP09_INCOME.;
	format strtms_primspec_grp strtms_rurprac_grp strtms_undrsvarea_grp strtms_undrsvpop_grp
	strtms_livrurcom_grp RP09_INTB.;
	format id RP09_NUMB.;
	format emplstat_grp RP09_PRACB.;
	format prepare_res_rurmdcn_grp RP09_PREPB.;
	format paymix_commins_grp RP09_Q27A.;
	format paymix_mdcr_grp RP09_Q27B.;
	format paymix_mdcd_grp RP09_Q27C.;
	format paymix_sp_sfs_grp RP09_Q27C.;
	format paymix_chp_grp RP09_Q27D.;
	format paymix_tri_grp paymix_other_grp RP09_Q27E.;
	format paymix_workcomp_grp RP09_Q27F.;
	format staffmodel_grp RP09_STFMDLGP.;
	format primary_urban_from_zip RP09_URBAN.;
	format satisf_numpts RP09_VISOP.;
	format incoff_loanrepay incoff_incguar incoff_prb_sal incoff_signbon incoff_benret incoff_part_shar
	incoff_flex incoff_limoncall incoff_locten incoff_spouse incoff_payst incoff_reloc
	incoff_oth visits_na obs_spec_reimb obs_spec_patcompl obs_spec_malprac obs_spec_insbenrest
	obs_spec_supspec ptaccess_allnew ptaccess_famonly ptaccess_sfs ptaccess_charcr
	ptaccess_closeadmdcd ptaccess_closechlmdcd ptaccess_closechp ptaccess_close_mdcr
	ptaccess_close_priv leave_12mo cuts_accpt_mdcr cuts_limit_mdcr cuts_close_mdcr
	cuts_undec_mdcr cuts_mdcr_serve RP09_YN.;
	format age_grp RP09AGEGRP.;
	format birth_yr_grp RP09BRTHYRGP.;
	format cnt_meded_hrs_grp RP09CNTMEDHRSGRP.;
	format mo_daysoncall_grp RP09DAYSONCALLGRP.;
	format grad_numyrs_grp RP09GDRNMYRGRP.;
	format grad_state_grp RP09GRADCO.;
	format grad_year_grp RP09GRADYRGRP.;
	format grad_age_grp RP09GRDAGEGRP.;
	format hours_dircare_wk_grp RP09HRSDIRCRGRP.;
	format hours_profcr_wk_grp RP09HRSPROFGRP.;
	format mdschl_motrain_grp RP09MTRNGRP.;
	format incr_mdcd_reib_grp covexp_mdcd_elg_grp sing_pyr_co_grp wv_liab_vol_grp
	loan_forgive_grp mdcdrsn_audits_grp mdcdrsn_doctime_grp mdcdrsn_noshow_grp RP09POL.;
	format pracloc_grp RP09PRACLOCGRP.;
	format prac_yr_grp RP09PRACYRGRP.;
	format prof_stat_grp RP09PRSTATC.;
	format race_grp RP09RACEGRP.;
	format satislf_persvswork_grp satislf_numhrs_grp satisf_malprac_grp
	satisf_qualcare_grp satisf_referrals_grp satisf_admin_grp satisf_ovrhd_grp
	satisf_income_grp satisf_clinvsadmin_grp RP09SATIS.;
	format specialty_grp RP09SPECGRP.;
	format visits_2008_grp RP09VIS08GRP.;
	format RUCA_Class_from_zip RPRUCGP.;
	format rurphywt ;
quit;
